#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: XaraLX-0.7r1780
# PROJECT HOMEPAGE 	: http://www.xaraxtreme.org
# SOURCE           	: http://downloads2.xara.com/opensource/XaraLX-0.7r1780.tar.bz2
#
# AUTHOR         	: skywatcher (skywatcher|AT|netsons|DOT|org, simone antoniucci)
# LATEST REVISION	: 2007/10/19

### Setting main variables
NAME="xaralx"
VERSION="0.7r1780"
ARCH="i486"
CPU="i686"
BUILD=50.1

HOMEPAGE="http://www.xaraxtreme.org"
DESCRIPTION="Vector graphics program"
SRCLNK="http://downloads2.xara.com/opensource/XaraLX-0.7r1780.tar.bz2"

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=XaraLX-$VERSION.tar.bz2
TAROPT="xvjf"
SRCDIR=$CWD/XaraLX-$VERSION
ICONDIR=$PKGDIR/usr/share/icons/hicolor/48x48/apps/		

BASE=http://users.zenwalk.org/user-accounts/skywatcher/

DOCS="ABOUT-NLS AUTHORS COPYING ChangeLog GPL INSTALL LICENSE NEWS README"

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION
mkdir -p $PKGDIR/usr/man/man1
mkdir -p $PKGDIR/usr/share/applications
mkdir -p $ICONDIR

### Checking if source is present. If it's not, download it
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
 	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Extracting source
tar $TAROPT $SRCPKG

### Configure, make, install
cd $SRCDIR
./configure --prefix=/usr --mandir=/usr/man --disable-debug --enable-filters --enable-svgfilter || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1
mv $PKGDIR/usr/bin/XaraLX $PKGDIR/usr/bin/xaralx

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "current ar archive" | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -a $DOCS $PKGDIR/usr/doc/$NAME-$VERSION
cp -a doc/xaralx.1 $PKGDIR/usr/man/man1
find $PKGDIR/usr/man -type f -exec gzip -9 {} \;

### Adding build-file to the package
cp -a $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Additional stuff
mkdir -p $PKGDIR/usr/share/$NAME/Examples
cp -a    Designs/*   $PKGDIR/usr/share/$NAME/Examples
cp -a -r Templates   $PKGDIR/usr/share/$NAME
cp -a -r TextDesigns $PKGDIR/usr/share/$NAME
mv $PKGDIR/usr/share/$NAME/Examples/LICENSE $PKGDIR/usr/doc/$NAME-$VERSION/LICENSE-EXAMPLES

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: Xara Xtreme for Linux is a powerful, general purpose graphics 
$NAME: program for Unix platforms. Formely known as Xara LX, it is based 
$NAME: on Xara Xtreme for Windows, which is the fastest graphics program 
$NAME: available. The Xara Xtreme source code was made available 
$NAME: open-source in early 2006, and is being ported to Linux.
$NAME: 
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

### Desktop entry
cd $SRCDIR
#sed -i 's@Exec=xaralx %F@Exec=XaraLX %F@' xaralx.desktop
#sed -i 's@TryExec=xaralx@TryExec=XaraLX@' xaralx.desktop
sed -i 's@Icon=xaralx.png@Icon=xaralx@' xaralx.desktop

cp -a xaralx.desktop $PKGDIR/usr/share/applications

### Icon
cp -a $SRCDIR/xaralx.png $ICONDIR/$NAME.png

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Making the package
makepkg -l y -c n $CWD/$PKG.tgz

### md5sum and dep
cd $CWD
md5sum $PKG.tgz > $PKG.md5
requiredbuilder -z $PKG.tgz > $PKG.dep

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

echo "To install type:"
echo "installpkg $PKG.tgz"
#Done. Ciao!
